==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/YesterdayExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { YesterdayExpressionDescription } from "./YesterdayExpressionDescription";
/**
 * @hidden
 */
var YesterdayExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(YesterdayExpressionDescriptionMetadata, _super);
    function YesterdayExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    YesterdayExpressionDescriptionMetadata.b = function (a) {
        if (YesterdayExpressionDescriptionMetadata.a == null) {
            YesterdayExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            YesterdayExpressionDescriptionMetadata.c(YesterdayExpressionDescriptionMetadata.a);
        }
        if (a.k(YesterdayExpressionDescriptionMetadata.a)) {
            return;
        }
        a.ab(YesterdayExpressionDescriptionMetadata.a);
    };
    YesterdayExpressionDescriptionMetadata.c = function (a) {
        WrapperExpressionDescriptionMetadata.c(a);
    };
    YesterdayExpressionDescriptionMetadata.d = function (a) {
        YesterdayExpressionDescriptionMetadata.b(a);
        a.ad("YesterdayExpression", function () { return new YesterdayExpressionDescription(); });
        a.ac("YesterdayExpression", YesterdayExpressionDescriptionMetadata.a);
    };
    YesterdayExpressionDescriptionMetadata.$t = markType(YesterdayExpressionDescriptionMetadata, 'YesterdayExpressionDescriptionMetadata');
    YesterdayExpressionDescriptionMetadata.a = null;
    return YesterdayExpressionDescriptionMetadata;
}(Base));
export { YesterdayExpressionDescriptionMetadata };

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm5/lib/YesterdayExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { YesterdayExpressionDescription } from "./YesterdayExpressionDescription";
/**
 * @hidden
 */
var YesterdayExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(YesterdayExpressionDescriptionMetadata, _super);
    function YesterdayExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    YesterdayExpressionDescriptionMetadata.b = function (a) {
        if (YesterdayExpressionDescriptionMetadata.a == null) {
            YesterdayExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            YesterdayExpressionDescriptionMetadata.c(YesterdayExpressionDescriptionMetadata.a);
        }
        if (a.k(YesterdayExpressionDescriptionMetadata.a)) {
            return;
        }
        a.ac(YesterdayExpressionDescriptionMetadata.a);
    };
    YesterdayExpressionDescriptionMetadata.c = function (a) {
        WrapperExpressionDescriptionMetadata.c(a);
    };
    YesterdayExpressionDescriptionMetadata.d = function (a) {
        YesterdayExpressionDescriptionMetadata.b(a);
        a.ae("YesterdayExpression", function () { return new YesterdayExpressionDescription(); });
        a.ad("YesterdayExpression", YesterdayExpressionDescriptionMetadata.a);
    };
    YesterdayExpressionDescriptionMetadata.$t = markType(YesterdayExpressionDescriptionMetadata, 'YesterdayExpressionDescriptionMetadata');
    YesterdayExpressionDescriptionMetadata.a = null;
    return YesterdayExpressionDescriptionMetadata;
}(Base));
export { YesterdayExpressionDescriptionMetadata };
